@@ -1,4 +1,4 @@
-#![doc(html_root_url = "https://docs.rs/guess_host_triple/0.1.4")]
+#![doc(html_root_url = "https://docs.rs/guess_host_triple/0.1.5")]
 #![warn(missing_docs)]
 //! Guess which Rust-supported platform is running the current code.
 //!
@@ -82,6 +82,7 @@ impl Architecture {
         use Architecture::*;
 
         match machine.to_bytes() {
+            b"amd64" => X86_64,
             b"arm" => Arm,
             b"armv7l" => ArmV7,
             b"armv8l" => ArmV8,
@@ -94,7 +95,7 @@ impl Architecture {
             b"powerpc" => PowerPc,
             b"powerpc64" => PowerPc64,
             _ => {
-                warn!("uname returned unrecognised machine {:?}", machine);
+                warn!("uname returned unrecognised machine {machine:?}");
                 Unknown
             }
         }
@@ -134,7 +135,7 @@ impl Os {
             b"NetBSD" => NetBsd,
             b"DragonFly" => DragonFly,
             _ => {
-                warn!("uname returned unrecognised sysname {:?}", sysname);
+                warn!("uname returned unrecognised sysname {sysname:?}");
                 Unknown
             }
         }
@@ -185,7 +186,7 @@ fn guess_triple_from_environment<E: Environment>(
         (X86_64, _, NetBsd) => Some("x86_64-unknown-netbsd"),
         (X86_64, _, DragonFly) => Some("x86_64-unknown-dragonfly"),
         other => {
-            warn!("Could not guess triple for {:?}", other);
+            warn!("Could not guess triple for {other:?}");
             None
         }
     }
