@@ -1,11 +1,11 @@
 //! Custom structs and enums for mac-notification-sys.
 
+use crate::error::{NotificationError, NotificationResult};
+use crate::{ensure, ensure_application_set, sys};
+use objc2::rc::Retained;
 use objc2_foundation::{NSDictionary, NSString};
 use std::default::Default;
 use std::ops::Deref;
-use objc2::rc::Retained;
-use crate::error::{NotificationError, NotificationResult};
-use crate::{ensure, ensure_application_set, sys};
 
 /// Possible actions accessible through the main button of the notification
 #[derive(Clone, Debug)]
@@ -72,6 +72,7 @@ pub struct Notification<'a> {
     pub(crate) delivery_date: Option<f64>,
     pub(crate) sound: Option<Sound>,
     pub(crate) asynchronous: Option<bool>,
+    pub(crate) wait_for_click: bool,
 }
 
 impl<'a> Notification<'a> {
@@ -230,6 +231,19 @@ impl<'a> Notification<'a> {
         self
     }
 
+    /// Allow waiting a response for notification click.
+    ///
+    /// # Example:
+    ///
+    /// ```no_run
+    /// # use mac_notification_sys::*;
+    /// let _ = Notification::new().wait_for_click(true);
+    /// ```
+    pub fn wait_for_click(&mut self, click: bool) -> &mut Self {
+        self.wait_for_click = click;
+        self
+    }
+
     /// Convert the Notification to an Objective C NSDictionary
     pub(crate) fn to_dictionary(&self) -> Retained<NSDictionary<NSString, NSString>> {
         // TODO: If possible, find a way to simplify this so I don't have to manually convert struct to NSDictionary
@@ -243,6 +257,7 @@ impl<'a> Notification<'a> {
             &*NSString::from_str("deliveryDate"),
             &*NSString::from_str("asynchronous"),
             &*NSString::from_str("sound"),
+            &*NSString::from_str("click"),
         ];
         let (main_button_label, actions, is_response): (&str, &[&str], bool) =
             match &self.main_button {
@@ -280,7 +295,9 @@ impl<'a> Notification<'a> {
                 Some(true) => "yes",
                 _ => "no",
             }),
+            // TODO: Same as above, if NSDictionary could support multiple types, this could be a boolean
             NSString::from_str(sound),
+            NSString::from_str(if self.wait_for_click { "yes" } else { "no" }),
         ];
         NSDictionary::from_retained_objects(keys, &vals)
     }
